# Bioez Package v 0.0.6

### [PyPi](https://pypi.org/project/bioezy/#description)

### [Github](https://github.com/Rukhan4/bioezy-package)


## Installation: `pip install bioezy`

## Usage: `from bioezy import bzy`


## Package details

Contains several bioinformatics scripts automating base level genomics analysis tasks. Methods mainly runs on genomic and Dna data, 
which are fully documented. Also contains an extensive analysis on E.Coli


